summaryrefslogtreecommitdiff
path: root/yaksh/xmlrpc_clients.py
diff options
context:
space:
mode:
Diffstat (limited to 'yaksh/xmlrpc_clients.py')
-rw-r--r--yaksh/xmlrpc_clients.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/yaksh/xmlrpc_clients.py b/yaksh/xmlrpc_clients.py
index 437dbcb..bb8260d 100644
--- a/yaksh/xmlrpc_clients.py
+++ b/yaksh/xmlrpc_clients.py
@@ -56,10 +56,10 @@ class CodeServerProxy(object):
Returns
-------
A json string of a dict containing:
- {"success": success, "weightage": weightage, "error": error message}
+ {"success": success, "weight": weight, "error": error message}
success - Boolean, indicating if code was executed successfully, correctly
weightage - Float, indicating total weightage of all successful test cases
error - String, error message if success is false
"""
@@ -68,7 +68,7 @@ class CodeServerProxy(object):
result = server.check_code(language, test_case_type, json_data, user_dir)
except ConnectionError:
result = json.dumps({'success': False,
- 'weightage': 0.0,
+ 'weight': 0.0,
'error': 'Unable to connect to any code servers!'})
return result
@@ -56,10 +56,10 @@ class CodeServerProxy(object):
success - Boolean, indicating if code was executed successfully, correctly
- weightage - Float, indicating total weightage of all successful test cases
+ weight - Float, indicating total weight of all successful test cases
error - String, error message if success is false
"""